@@ -8,13 +8,12 @@ from kaa.filetype.javascript import javascriptmode
 from kaa.filetype.css import cssmode
 
 HTMLThemes = {
-    'basic':
-    Theme([
+    'basic': [
         Style('html-decl', 'Red', 'default'),
         Style('html-tag', 'Magenta', 'default'),
         Style('html-attrname', 'green', 'default'),
         Style('html-attrvalue', 'yellow', 'default'),
-    ]),
+    ],
 }
 
 
