@@ -1,3 +1,4 @@
+import unicodedata
 import copy
 from collections import namedtuple
 from kaa.filetype.default import defaultmode
@@ -8,8 +9,7 @@ from kaa.command import Commands, command, norec, norerun
 from kaa.keyboard import *
 
 RstThemes = {
-    'basic':
-    Theme([
+    'basic': [
         Style('header', 'Blue', None),
         Style('block', 'Orange', None),
         Style('directive', 'Green', None),
@@ -20,14 +20,19 @@ RstThemes = {
         Style('reference', 'Red', None),
         Style('role', 'Cyan', None),
         Style('substitution', 'Green', None),
-    ]),
+    ],
 }
 
 
+SEP_CHARS = ''.join(
+    c for c in (chr(i) for i in range(0x12000))
+    if unicodedata.category(c) in {'Pd', 'Po', 'Ps', 'Pi', 'Pf'})
+
+
 class RstInline(Span):
     WS = ' \t\r\n'
-    STARTS = '\'"([{<' + WS
-    ENDS = '\'".,:;!?-)]}/\\>' + WS
+    STARTS = '\'"([{<' + WS + SEP_CHARS
+    ENDS = '\'".,:;!?-)]}/\\>' + WS + SEP_CHARS
 
     def on_start(self, tokenizer, doc, pos, match):
         if ((pos and (doc.gettext(pos - 1, pos) not in self.STARTS)) or
