@@ -10,10 +10,7 @@ from kaa.ui.selectlist import filterlist
 from gappedbuf.sre_constants import error as gre_error
 
 SearchThemes = {
-    'basic':
-    Theme([
-    ]),
-
+    'basic': [],
 }
 
 
@@ -49,7 +46,8 @@ class SearchCommands(editorcommand.EditCommands):
 
         self._show_histdlg(wnd, 'Recent searches',
                            [s for s,
-                               info in kaa.app.config.hist('search_text').get()],
+                               info in kaa.app.config.hist(
+                                   'search_text').get()],
                            callback)
 
     @command('searchdlg.toggle.ignorecase')
